reconstruct_python_custom_data

Function reconstruct_python_custom_data 

pub fn reconstruct_python_custom_data(
    py: Python<'_>,
    type_name: &str,
    json: &str,
) -> PyResult<Py<PyAny>>
Reconstructs a Python custom data instance from type name and JSON.

Errors

Returns a Python error if no class is registered for type_name or JSON parsing fails.